Changelog
=========


1.0b9 (2020-04-01)
------------------

- Add imio.prometheus dependency.
  [bsuttor]

- Add collective.folderishtypes [dexterity] dependency.
  [bsuttor]


1.0b8 (2020-03-25)
------------------

- Bad release.
  [bsuttor]


1.0b7 (2020-03-25)
------------------

- Add collective.prometheus dependency.
  [bsuttor]


1.0b6 (2020-01-29)
------------------

- Add collective.sendinblue dependency
  [laulaz]


1.0b5 (2020-01-29)
------------------

- Add core and remove taxonomy dependency.
  [bsuttor]


1.0b4 (2020-01-27)
------------------

- Add collective.faceted.map dependency.
  [bsuttor]

- Add collective.geolocationbehavior dependency.
  [bsuttor]


1.0b3 (2019-12-16)
------------------

- Add pas.plugin.imio dependency.
  [bsuttor]


1.0b2 (2019-11-26)
------------------

- Add buildout index
- Make works with py3
  [bsuttor]


1.0b1 (2019-02-25)
------------------

- Add iaweb.mosaic dependency.
  [bsuttor]


1.0a2 (2018-12-10)
------------------

- Upload to devpi.
  [bsuttor]


1.0a1 (2018-12-10)
------------------

- Initial release.
  [daggelpop]
